package com.uncontrol{
	/**
	 * @author manny tan / uncontrol
	 */
	public class Utils
	{
		
		/**
		 * creates a set of values that lie along a sinusoidal curve aka 'hump'
		 * @param scrubber		Position in relation to total (aka i/total).
		 * @param offset		Location of 'hump'
		 * @param rangeDouble	Width of plateau of 'hump' .
		 * @param diameter		Slope width from plateau to flat.
		 * @param amplitude		Height of 'hump'.
		 * @param isInteger		Determines if the return value is an int.
		 * @return 
		 */
		public static function getCurveValue(		scrubber:Number=0.0, 	offset:Number=0.0, rangeDouble:Number = 0.0,	diameter:Number=.25, 	amplitude:Number=50,	isInteger:Boolean=false):Number{
			var yPos:Number;
			var range:Number = rangeDouble/2;	
		   if(	scrubber < (offset-diameter/2-range)	){													// zone 1
				yPos = 0; 
			} else if(	(offset+diameter/2+range) <= scrubber	){											// zone 5
				yPos = 0;
			} else if( scrubber >= (offset-diameter/2-range) && scrubber < (offset-range)	){				// zone 2
				yPos = (Math.cos( ( scrubber - offset + range) / diameter * (Math.PI * 2) ) * amplitude + amplitude) / 2;
			} else if(	scrubber >= (offset+range)  &&  scrubber < (offset+diameter/2+range)	){			// zone 4
				yPos = (Math.cos( ( scrubber - offset - range) / diameter * (Math.PI * 2) ) * amplitude + amplitude) / 2;
			} else {																						// zone 3
				yPos = amplitude;
			}

			if(isInteger){
				yPos = int(yPos);
			}

			return yPos;
		}
		
		/**
		 * returns boolean based off of where the arg is
		 * @param	arg	Number 
		 * @param	a
		 * @param	b
		 * @return
		 */
		public static function getRange(arg:Number,a:Number,b:Number):Boolean{
			if(a<=arg && arg<=b){
				return true
			}
			return false;
		}

		/**
		 * searchs a string and replaces text accordingly
		 * @param	str		entire string
		 * @param	find	find string
		 * @param	replace	replace with
		 * @return
		 */
		public static function replaceString(str:String, find:String, replace:String):String {
			var startIndex:Number = 0;
			var oldIndex:Number = 0;
			var newString:String = "";

			while ((startIndex = str.indexOf(find, startIndex)) != -1) {
				newString += str.substring(oldIndex, startIndex) + replace;
				oldIndex = startIndex += find.length;
			}

			return((newString == "") ? str : newString);
		}
		
		/**
		 * creates an array of random values between 0-length
		 * values are only used once
		 * @param	total		
		 * @return
		 */
		public static function shuffleArray(total:Number=0):Array{
			var a:Array = new Array();
			var b:Array = new Array();
		    for (var i=0; i<total; i++) {
		        a.push(i);
		    }
		    while (a.length>0) {
		        b.push(a.splice(	int(Math.random()*a.length)	, 1));
		    }
			return b;
		}
   
		/**
		 * roundToNearest value 
		 * @param	roundTo
		 * @param	value
		 * @return
		 */
		public static function roundToNearest(roundTo:Number, value:Number):Number{
			return Math.round(value/roundTo)*roundTo;
		}
		
		/**
		 * rounds number to nearest decimal
		 * @param	num number to be decimaled
		 * @param	decimal number of digits after decimal
		 * @return
		 */
		public static function roundToDecimal(num:Number, decimal:int = 5):Number {
			var pow:Number = Math.pow(10, decimal);	
			return (int(num * pow) / pow);	
		}
	}
}
